# -*- coding: utf-8 -*-
# @Time    : 2022/5/7 22:35
# @Author  : hxq
# @Software: PyCharm
# @File    : session.py
from typing import Union
from requests import Session
from requests.structures import CaseInsensitiveDict
from requests.utils import default_headers

from hxq.libs.httpx.http import HTTPRequest, requests_catch_exception, HTTPResponse, HTTPError
from hxq.libs.httpx.chrome_agent import random_version


class SessionRequest(HTTPRequest):
    """基于requests 方便日常使用的简单二次封装"""

    def __init__(self, ignore_status=True):
        """
        :param ignore_status: 是否忽略错误状态码
        """
        self.__http = Session()
        self.headers = {"User-Agent": random_version()}
        self.ignore_status = ignore_status

    def get(self, url, params=None, timeout=None, proxies=None, **kwargs) -> Union[HTTPResponse, HTTPError]:
        """
        GET请求
        """
        kwargs.setdefault('allow_redirects', True)
        r = self.request('GET', url, params=params, timeout=timeout, proxies=proxies, **kwargs)
        r.close()
        return r

    def post(self, url, data=None, timeout=None, proxies=None, **kwargs) -> Union[HTTPResponse, HTTPError]:
        """
        POST请求
        """
        r = self.request('POST', url, data=data, timeout=timeout, proxies=proxies, **kwargs)
        r.close()
        return r

    def download(self, url, file_path=None, params=None, data=None, **kwargs):
        """
        session 下载文件
        """
        return HTTPRequest.download(url, request=self.request, file_path=file_path, params=params, data=data, **kwargs)

    @requests_catch_exception
    def request(self, method, url, **kwargs):
        """
        :param method: 大小不敏感，在Session内部upper统一转化为大写
        :param url: 地址
        :param kwargs:
        :return:
        """
        # with self.__http.request(method, url, **kwargs) as r:
        results = HTTPResponse(self.__http.request(method, url, **kwargs))
        if not self.ignore_status and results.code != 200:
            return HTTPError(results.code, '请求状态错异常!')
        return results

    @property
    def cookies(self) -> dict:
        """
        读取cookies
        """
        return self.cookiejar2dict(self.__http.cookies)

    @cookies.setter
    def cookies(self, cookie: dict):
        """
        设置cookies
        """
        self.__http.cookies = self.dict2cookiejar(cookie)

    @property
    def headers(self) -> CaseInsensitiveDict:
        """
        读取当前headers
        """
        self.__http.headers.items()
        return self.__http.headers

    @headers.setter
    def headers(self, header: dict or str):
        """
        设置headers
        """
        self.__http.headers.clear()
        self.__http.headers = default_headers()
        self.add_headers(header)

    def add_headers(self, header: dict or str) -> CaseInsensitiveDict:
        """
        追加headers
        """
        if isinstance(header, str):
            header = self._raw_headers_to_dict(header)
        if isinstance(header, dict):
            return [self.__http.headers.update({k: v}) for k, v in header.items()].clear() or self.__http.headers



"""
1、 填充字符串和明文字符串最后一位不能相同
2、 字符串编码默认是utf-8， key和iv默认为英文字符；字符串不支持其他编码或key/iv不支持为中文字符
"""
import base64
from enum import Enum, unique

from Crypto.Cipher import AES


@unique
class Mode(Enum):
    CBC = AES.MODE_CBC
    ECB = AES.MODE_ECB


@unique
class Padding(Enum):
    """ 定义填充的字符串 """
    SPACE = ' '  # 空格


class AES256Crypto:
    def __init__(self, key, mode=Mode.ECB, padding=Padding.SPACE, iv=None):

        """
        :param key: 密钥， 32byte 长度字符串
        :param mode: 加密模式， 来源 class Mode
        :param iv: 16byte 长度字符串
        :param padding: 填充的字符串， 来源class Padding
        """
        self.padding = self.check_padding(padding)
        self.key = self.padding_key(key)
        self.iv = self.padding_iv(iv) if iv else None
        self.mode = self.check_mode(mode)

    def check_mode(self, mode):
        """ 核对 mode """
        if mode not in Mode.__members__.values():
            raise Exception(f'mode {mode} not allowed!')
        if mode == Mode.CBC and not self.iv:
            raise Exception(f'iv is required')
        return mode

    @staticmethod
    def check_padding(padding):
        """ 核对 padding """
        if padding not in Padding.__members__.values():
            raise Exception(f'mode {padding} not allowed!')
        return padding

    def padding_ret_byte(self, text, _len=16):
        """ 填充并转成 bytes """
        text = text.encode()
        remainder = len(text) % _len
        remainder = _len if remainder == 0 else remainder
        text += (_len - remainder) * self.padding.value.encode()
        return text

    def padding_iv(self, iv: str):
        """ 补全iv 并转成 bytes"""
        if len(iv.encode()) > 16:
            raise Exception(f'iv {iv} must <= 16bytes')
        return self.padding_ret_byte(iv)

    def padding_key(self, key: str):
        """ 补全key 并转成 bytes """
        if len(key.encode()) > 32:
            raise Exception(f'key {key} must <= 32bytes')
        return self.padding_ret_byte(key, _len=32)

    def encrypt(self, text, encode=base64.b16encode):
        """
        加密
        :param text: 待加密字符串
        :param encode: 传入base64里面的方法
        :return: 若encode=None则不进行base加密处理，返回bytes类型数据
        """
        text = self.padding_ret_byte(text)
        # 注意：加密中的和解密中的AES.new()不能使用同一个对象，所以在两处都使用了AES.new()
        text = AES.new(key=self.key, mode=self.mode.value, iv=self.iv).encrypt(text)
        if encode:
            return encode(text).decode()
        return text

    def decrypt(self, text, decode=base64.b16decode):
        """ 解密 """
        if decode:
            if type(text) == str:
                text = text.encode()
                text = decode(bytes(text))
            else:
                if type(text) != bytes:
                    raise Exception(text)
        text = AES.new(key=self.key, mode=self.mode.value, IV=self.iv).decrypt(text)
        text = text.strip(self.padding.value.encode())
        return text.decode()


if __name__ == '__main__':
    # if sys.argv[1] is not None and sys.argv[2] is not None:
    #     key = sys.argv[1]
    #     sourceStr = sys.argv[2]
    # else:
    key = input('Please enter key:')
    sourceStr = input('Please enter str:')
    argus_iv = 'NjtPECu47eSOm36s'
    argus_AES = AES256Crypto(key, Mode.CBC, Padding.SPACE, argus_iv)
    print('Plaintext:', sourceStr)
    encryptedpassword = argus_AES.encrypt(sourceStr)
    print('Encrypted string:', encryptedpassword)
    password = argus_AES.decrypt(encryptedpassword)
    print('Decrypted string:', password)
    decryptStr = input('Please enter Encrypted string:')
    print('Decrypted string:', argus_AES.decrypt(decryptStr))



# -*- coding: utf-8 -*-
# @Time    : 2023/4/6 23:38
# @Author  : hxq
# @Software: PyCharm
# @File    : db.py
import time
from hxq.libs.db import DBHelper

__all__ = [
    "DBHelper",
]

if __name__ == '__main__':
    CONFIG = {
        'SQL_CREATOR' : 'sqlite3',
        'SQL_DATABASE': r'blog.sqlite3'
    }
    db = DBHelper(config=CONFIG)

    # input(db.get_placeholder(2))
    create_table = '''
    CREATE TABLE IF NOT EXISTS hxq(
       ID INTEGER PRIMARY KEY AUTOINCREMENT,
       NAME           TEXT    NOT NULL,
       AGE            INT     NOT NULL,
       ADDRESS        CHAR(50),
       SALARY         REAL
    );
    '''
    db.execute(create_table)

    data_list = []
    for i in range(10):
        data_list.append(('test', f'{i}'))
    print(db.get_placeholder())
    sql = f"INSERT INTO hxq('NAME','AGE') VALUES ({db.get_placeholder(2)})"
    print(sql)
    db.executemany(sql, data_list)

    r = db.all("select * from hxq")
    print(r)
    if isinstance(r, list):
        for i in r:
            print(i)
    else:
        print(r)

    print(len(r))



import os
import time
import logging
from logging.handlers import TimedRotatingFileHandler


class Log(logging.Logger):
    CRITICAL = 50
    FATAL = CRITICAL
    ERROR = 40
    WARNING = 30
    WARN = WARNING
    INFO = 20
    DEBUG = 10
    NOTSET = 0

    def __init__(self, logs_path='logs', level=NOTSET, stream=True, file=True):
        """
        logs_path:log储存文件地址,默认为logs
        stream:是否输出到控制台
        file:是否保存到文件
        """
        self.level = level
        self.stream = stream
        self.file = file
        super().__init__(__name__, level=level)
        # 设置输出格式，依次为，线程，时间，名字，信息。
        self.fmt = '[%(asctime)s] %(levelname)s [%(filename)s:%(lineno)-3d] %(threadName)s [%(name)s]:%(message)s'
        self.logs_path = logs_path  # logs文件夹

    def set_name(self, name=''):
        """
        file_name：保存的文件名
        name:日志名字
        """
        # 解决重复输出的问题
        if self.handlers:
            return
        if self.stream:
            self.__set_stream_handler__()
        if self.file:
            self.__set_file_handler__(name)
        return self

    def reset_name(self, name):
        """
        重置文件名
        :param name:文件名称
        :return:
        """
        self.name = name
        self.removeHandler(self.file_handler)
        self.__set_file_handler__(name)
        return self

    def __set_file_handler__(self, file_name: str):
        """
        设置输出文件
        """
        # 去除影响文件名称不规范的杂质
        for item in r'\/:*?!`~^&%$"<>|;':
            file_name = file_name.replace(item, '')
        self.name = file_name or self.name
        # file_name = [file_name := file_name.replace(char, '') for char in r'\/:*?"<>|;'].pop()  # 3.8以上 去除非法文件字符
        logs_dir = '{}/{}-Logs'.format(self.logs_path, file_name)
        if os.path.exists(logs_dir) and os.path.isdir(logs_dir):  # 存在且是文件夹
            pass
        else:
            os.makedirs(logs_dir)
        # 修改log保存位置和文件名
        # time_stamp = time.strftime("%Y-%m-%d", time.localtime())
        # log_file_name = '{}.txt'.format(time_stamp)
        filename = os.path.join(logs_dir, 'log.txt')
        # 设置日志回滚, 保存在log目录, 一天保存一个文件, 保留365天
        file_handler = TimedRotatingFileHandler(filename=filename, when='midnight', interval=1, backupCount=365,
                                                encoding='utf-8')
        file_handler.setLevel(self.level)
        formatter = logging.Formatter(self.fmt, '%Y-%m-%d %H:%M:%S')
        file_handler.setFormatter(formatter)
        self.file_handler = file_handler
        self.addHandler(file_handler)

    def __set_stream_handler__(self):
        """
        设置控制台输出
        """
        stream_handler = logging.StreamHandler()
        formatter = logging.Formatter(self.fmt, '%Y-%m-%d %H:%M:%S')
        stream_handler.setFormatter(formatter)
        stream_handler.setLevel(self.level)
        self.addHandler(stream_handler)


my_log = Log()



# -*- coding: utf-8 -*-
# @Time    : 2022/3/4 10:33
# @Author  : hxq
# @Software: PyCharm
# @File    : httpx.py
from hxq.libs.httpx.http import HTTPRequest
from hxq.libs.httpx.session import SessionRequest

__all__ = [
    "http",
    "HTTP",
]
HTTP = SessionRequest
http = HTTPRequest



# -*- coding: utf-8 -*-
# @Time    : 2022/7/10 20:40
# @Author  : hxq
# @Software: PyCharm
# @File    : encipher.py
# 加密类
import base64
import hashlib


def encode_bytes(data):
    if isinstance(data, str):
        return data.encode('utf-8')
    if isinstance(data, bytes):
        return data
    raise TypeError('传入类型错误')


# 加密器
class Encipher(object):
    @staticmethod
    def get_file_md5(file):
        with open(file, 'rb') as f:
            h1 = hashlib.md5()
            data = f.read(10240)
            while data:
                h1.update(data)
                data = f.read(10240)
        return h1.hexdigest()

    @staticmethod
    def get_file_base64(fp):
        with open(fp, 'rb') as f:
            return base64.b64encode(f.read())

    @staticmethod
    def md5(data):
        """
        md5加密
        """
        return hashlib.md5(encode_bytes(data)).hexdigest()

    @staticmethod
    def hash(data):
        """
        哈希加密
        """
        return hashlib.sha1(encode_bytes(data)).hexdigest()

    @staticmethod
    def base64(data):
        """
        base64编码
        """
        return base64.b64encode(encode_bytes(data)).decode('utf-8')

    @staticmethod
    def debase64(string):
        """
        base64解码
        """

        return base64.b64decode(encode_bytes(string)).decode("utf-8")


if __name__ == '__main__':
    print(Encipher.get_file_md5('encipher.py'))



import os.path
from fnmatch import fnmatch
import win32com.client as win32


class ExcelHandler:

    def __init__(self, visible=True):
        self.xApp = win32.Dispatch('Excel.Application')
        self.xApp.Visible = visible
        self.xApp.DisplayAlerts = False
        self.workbook = None
        self.active_sheet = None

    def open(self, file_path, sheet_name=None, unprotect=False, password=None):
        self.workbook = self.xApp.Workbooks.Open(file_path, UpdateLinks=0)
        # 设置 DisplayAlerts 为 False 以禁止弹窗警告
        self.sheet(sheet_name or 1, unprotect, password)
        if unprotect is True:
            self.workbook.Unprotect()

    def get_last_used_row(self):
        used_range = self.active_sheet.UsedRange
        return used_range.Rows(used_range.Rows.count).Row

    def find_sheets(self, name):
        return list(filter(lambda _: fnmatch(_.Name, name), self.workbook.Sheets))

    def find_sheet(self, name):
        r = self.find_sheets(name)
        return r[0] if r else None

    def sheet(self, sheet_name, unprotect=False, password=None):
        self.active_sheet = self.workbook.Sheets(sheet_name)
        if unprotect:
            self.active_sheet.Unprotect(password)

    def read_cell(self, w, h):
        return self.active_sheet.cells(h, w)

    def write_cell(self, x, y, value):
        self.active_sheet.cells(y, x).Value = value

    def write_range(self, x, y, data):
        start_cell = self.active_sheet.Cells(y, x)  # 起始单元格
        end_cell = self.active_sheet.Cells(y, x + len(data) - 1)  # 结束单元格
        range_to_write = self.active_sheet.Range(start_cell, end_cell)
        range_to_write.Value = data

    def delete_cell(self, w, h):
        self.active_sheet.cells(h, w).Delete()

    def add_sheet(self, sheet_name):
        new_sheet = self.workbook.Sheets.Add()
        new_sheet.Name = sheet_name
        self.active_sheet = new_sheet

    def save_as(self, new_filename):
        if os.path.exists(new_filename):
            os.remove(new_filename)
        self.workbook.SaveAs(new_filename)

    def save(self):
        self.workbook.Save()

    def close(self):
        self.workbook.Close(SaveChanges=False)
        # self.xApp.Quit()
        self.quit()

    def quit(self):
        self.xApp.Quit()

    def inject_vba(self, macro_code):
        """注入vba代码
        1：标准模块
        2：类模块
        3：用户窗体
        """
        xlmodule = self.workbook.VBProject.VBComponents.Add(1)
        xlmodule.CodeModule.AddFromString(macro_code)

    def run_vba(self, fun_name, *arge):
        """执行vba"""
        self.workbook.Application.Run(fun_name, *arge)


def isFloat(s):
    try:
        float(s)
        return True
    except Exception as e:
        return False


if __name__ == '__main__':
    handler = ExcelHandler()
    handler.open(os.path.join(os.path.abspath('..'), 'templates/WebADI.xlsm'), unprotect=True)
    # 往excel写入vba code,及运行vba
    code = '''
    Sub VBAMacro(a,b)
        Dim sh As Worksheet
        Sheet1.Range("E12") = a
        Sheet1.Range("E13") = b
    End Sub
            '''
    handler.inject_vba(code)
    handler.run_vba('VBAMacro', 123123, 6666)

    # handler.open(r"C:\Users\xingqiao.he\Desktop\贝壳\LJ67-240126-02042北京公寓底租成本-闪店计算表.xlsx",
    #              sheet_name="核算指引")
    # sheet = handler.find_sheet("见合-酒*")
    # print(sheet)
    # print(sheet.Name)
    # row3 = handler.active_sheet.Range("A3:BB3")
    # row4 = handler.active_sheet.Range("A4:BB4")
    # find_column = ""
    # # 检查第三行和第四行的每个单元格
    # for cell in row3:
    #     if cell.Value == '24.1月入账' and row4[cell.Column - 1].value == "北京见合-酒店":
    #         find_column = f"{cell.Address}:{cell.Address.split('$')[1]}100"
    #         print(f"The column that satisfies the condition is column {find_column}")
    #         break
    # # 遍历第二列
    # for i in handler.active_sheet.Range(find_column):
    #     if i.value and str(i.value) != "0.0" and str(i.value) != "0" and isFloat(i.value):
    #         print(handler.read_cell(6, i.Row).value)

    # 显示筛选结果
    # handler.active_sheet.UsedRange.AutoFilter.ShowAllItems
    # handler.save_as(os.path.join(os.getcwd(), "adi.xlsm"))
    # handler.close()



# -*- coding: utf-8 -*-
# @Time    : 2022/4/5 12:51
# @Author  : hxq
# @Software: PyCharm
# @File    : __init__.py.py
import os
import importlib
import getpass

winshell = importlib.import_module("winshell")


class Client:
    def __init__(self):
        ...

    @property
    def desktop(self):
        """
        桌面路径
        """
        return getattr(winshell, 'desktop')()

    @property
    def username(self):
        """
        系统用户名
        """
        return getpass.getuser()

    @staticmethod
    def start_file(path):
        """
        启动文件/应用
        """
        os.startfile(path)

    @property
    def startup_path(self) -> str:
        """
        自启动目录
        """
        startup_path = r"AppData\Roaming\Microsoft\Windows\Start Menu\Programs\Startup"
        return os.path.join(os.getenv("SystemDrive"), r"\users", self.username, startup_path)

    @staticmethod
    def create_shortcut(exe_path: str, shortcut_name: str, desc: str):
        """
        生成快捷方式
        :param exe_path: exe路径
        :param shortcut_name: 需要创建快捷方式的路径
        :param desc: 描述，鼠标放在图标上面会有提示
        :return:
        """
        if not shortcut_name.endswith('.lnk'):
            shortcut_name = shortcut_name + ".lnk"
        try:
            getattr(winshell, 'CreateShortcut')(
                Path=shortcut_name,
                Target=exe_path,
                Icon=(exe_path, 0),
                Description=desc
            )
            return True
        except ImportError as err:
            print("'winshell' lib may not available on current os")
            print("error detail %s" % str(err))
        return False

    def create_startup(self, exe_path: str, lnk_name: str, desc: str):
        return self.create_shortcut(exe_path, os.path.join(self.startup_path, lnk_name), desc)



# -*- coding: utf-8 -*-
# @Time    : 2022/12/6 23:18
# @Author  : hxq
# @Software: PyCharm
# @File    : __init__.py
import contextlib
import re
import json
import datetime
import importlib
from typing import Union
from json import JSONEncoder
from decimal import Decimal
from dbutils.pooled_db import PooledDB, PooledDedicatedDBConnection

from hxq.utils.decorator import func_run_times


class DateTimeEncoder(JSONEncoder):
    def default(self, obj):
        if isinstance(obj, (datetime.date, datetime.datetime)):
            return obj.isoformat(sep=" ")
        elif isinstance(obj, Decimal):
            return str(obj)
        return super().default(obj)


class DBHelper:
    """简单的数据库连接池助手"""
    sql_conns = {
        'mysql'  : 'pymysql',
        'mssql'  : 'pymssql',
        'sqlite3': 'sqlite3'
    }

    def __init__(self, config):
        """
        初始化连接池
        :param config:
        """
        self.config = self.import_config(config)
        self.pool = None
        self.dbtype = self.config.setdefault('SQL_CREATOR', 'mysql').lower()
        database = importlib.import_module(self.sql_conns.get(self.dbtype))
        if self.sql_conns.get(self.dbtype) == "sqlite3":
            self.pool = PooledDB(
                creator=database,
                maxconnections=self.config.setdefault('SQL_MAX_CONNECT', 16),
                mincached=self.config.setdefault('SQL_MIN_CACHED', 1),
                blocking=self.config.setdefault('SQL_BLOCKING', True),
                database=self.config.setdefault('SQL_DATABASE', None),
            )
        else:
            self.pool = PooledDB(
                creator=database,
                maxconnections=self.config.setdefault('SQL_MAX_CONNECT', 16),
                mincached=self.config.setdefault('SQL_MIN_CACHED', 1),
                blocking=self.config.setdefault('SQL_BLOCKING', True),
                ping=self.config.setdefault('SQL_PING', 0),
                host=self.config.setdefault('SQL_HOST', '127.0.0.1'),
                port=self.config.setdefault('SQL_PORT', 3306),
                user=self.config.setdefault('SQL_USER', 'root'),
                password=self.config.setdefault('SQL_PASSWORD', None),
                database=self.config.setdefault('SQL_DATABASE', None),
                charset=self.config.setdefault('SQL_CHARSET', 'utf8mb4')
            )

    """导入配置"""

    @staticmethod
    def import_config(obj) -> dict:
        """
        导入字典or类对象中的配置信息
        """
        config = dict()
        if isinstance(obj, dict):
            [config.update({k.upper(): v}) for k, v in obj.items()]
        elif hasattr(obj, '__dict__'):
            [config.update({k: getattr(obj, k)}) if k.isupper() else '' for k in dir(obj)]
        else:
            raise ValueError('请导入正确的config对象!')
        return config

    def get_placeholder(self, num=1):
        """
        根据数据库类型选择占位符
        :return:
        """
        if self.dbtype == "mysql":
            return ','.join(['%s'] * num)
        elif self.dbtype == "mssql":
            return ','.join(['%s'] * num)
        elif self.dbtype == "sqlite3":
            return ','.join(['?'] * num)
        raise ValueError("Unsupported database type")

    @staticmethod
    def _tuple2dict(results, cursor) -> list:
        """
        列表类型转字典
        :param results:
        :param cursor:
        :return:
        """
        desc = list(map(lambda x: x[0], cursor.description))
        result = [dict(zip(desc, item)) for item in results]
        #  json.dumps(result, cls=DateTimeEncoder)
        return json.loads(DateTimeEncoder().encode(result))

    @contextlib.contextmanager
    def auto_commit(self, begin: bool = False):
        """
        用于批量或多个sql执行的自动提交管理
        示例1:
        with self.auto_commit() as cursor:
            cursor.executemany(sql_statement, values)
        示例2:
        with db.auto_commit(True) as cursor:
            for i in range(1000000):
                cursor.execute(f"INSERT INTO hxq('NAME','AGE') values('{i}')")
        """
        with self.connect() as conn:
            if begin is True:
                conn.begin()
            cursor = conn.cursor()
            try:
                yield cursor
                conn.commit()
            except Exception as e:
                conn.rollback()
                raise e
            finally:
                if cursor:
                    cursor.close()

    def executemany(self, sql_statement, values: list):
        """
        批量执行sql
        :param sql_statement:
        :param values:
        :return:
        """
        with self.connect() as conn:
            cursor = conn.cursor()
            try:
                cursor.executemany(sql_statement, values)
                conn.commit()
            except Exception as e:
                conn.rollback()
                raise e
            finally:
                if cursor:
                    cursor.close()

    # @func_run_times()
    def execute(self, sql_statement: str) -> Union[list, dict, int]:
        """
        执行增删改查sql语句
        :param sql_statement:
        :return:
        """
        with self.connect() as conn:
            cursor = conn.cursor()
            row_count = cursor.execute(sql_statement)
            # 匹配对大小写不敏感 ,SELECT|SHOW开头
            if re.search(r"^(SELECT|SHOW)", sql_statement, re.I):
                result = cursor.fetchall()
                return self._tuple2dict(result, cursor)
            cursor.connection.commit()
            cursor.close()
            return row_count if row_count else 0

    # @func_run_times()
    def first(self, sql_statement) -> dict:
        """
        查询一条数据
        :param sql_statement:
        :return:
        """
        with self.connect() as conn:
            cursor = conn.cursor()
            cursor.execute(sql_statement)
            result = cursor.fetchone()
            cursor.close()
        if not result:
            return {}
        return self._tuple2dict([result], cursor)[0]

    # @func_run_times()
    def all(self, sql_statement) -> list:
        """
        查询所有数据
        :param sql_statement:
        :return:
        """
        with self.connect() as conn:
            cursor = conn.cursor()
            cursor.execute(sql_statement)
            result = cursor.fetchall()
            cursor.close()
        if not result:
            return []
        return self._tuple2dict(result, cursor)

    @contextlib.contextmanager
    def connect(self) -> PooledDedicatedDBConnection:
        """
        创建连接
        :return:
        """
        conn = self.pool.connection()
        try:
            yield conn
        finally:
            self.close(conn)

    @staticmethod
    def close(conn):
        """
        关闭连接
        :param conn:
        :return:
        """
        # conn.cursor().close()
        if conn:
            conn.close()

    # def __enter__(self):
    #     """
    #     # 实现with obj as f 主动从连接池中拿连接对象 并存放至线程堆中
    #     """
    #     conn, cursor = self.connect()
    #     return cursor
    #
    # def __exit__(self, exc_type, exc_val, exc_tb):
    #     """
    #     # 实现with 结束 从线程堆中获取链接对象，并回收连接至连接池
    #     """
    #     print(exc_type, exc_val, exc_tb)



# -*- coding: utf-8 -*-
# @Time    : 2023/4/6 23:25
# @Author  : hxq
# @Software: PyCharm
# @File    : pic_code.py
import importlib


def qrcode(text):
    qr_code = importlib.import_module('qrcode')
    qr = getattr(qr_code, "QRCode")(version=1, box_size=10, border=5)
    qr.add_data(text)
    qr.make(fit=True)
    img = qr.make_image(fill='black', back_color='white')
    img.save('qrcode_img.png')


if __name__ == '__main__':
    qrcode("qrcode_img.png")
